沉默的羔羊 (豆瓣)
Description: 沉默的羔羊电影简介和剧情介绍,沉默的羔羊影评、图片、预告片、影讯、论坛、在线购票
Keywords: 沉默的羔羊,The Silence of the Lambs,沉默的羔羊影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.77豆瓣电影Top250

# 沉默的羔羊 The Silence of the Lambs (1991)

导演: 乔纳森·戴米
编剧: 托马斯·哈里斯 / 泰德·塔里
主演: 朱迪·福斯特 / 安东尼·霍普金斯 / 斯科特·格伦 / 安东尼·希尔德 / 布鲁克·史密斯 / 卡斯·莱蒙斯 / 弗兰基·费森 / 泰德·拉文 / 崔西·沃特 / 丹·巴特勒 / 达拉
类型: 剧情 / 惊悚 / 犯罪
制片国家/地区: 美国
语言: 英语
上映日期: 1991-02-14(美国)
片长: 118分钟
IMDb: tt0102926
豆瓣评分
引用
8.9
839157人评价
5星
53.9%
4星
37.8%
3星
7.7%
2星
0.4%
1星
0.1%
好于 99% 惊悚片
好于 98% 犯罪片
想看 看过
评价:
推荐

## 沉默的羔羊的剧情简介 · · · · · ·

联调局学院学员 Clarice M. Starling（乔迪·福斯特 饰）受行为科学组的 Jack Crawford（斯科特·格伦 饰）指派，前往州立巴尔的摩法医院访问被监禁的精神科医生 Hannibal Lecter（安东尼·霍普金斯 饰）。Lecter要求转到条件较 好的联邦机构，远离常常折磨他的 Frederick Chilton 医生（安东尼·希尔德 饰），并愿意为此提供持续作案的连环杀手水牛比尔（泰德·莱文 饰）的心理分析…… ©豆瓣

## 沉默的羔羊的演职员 · · · · · · ( 全部 37 )

- 乔纳森·戴米 导演
- 朱迪·福斯特 饰 克拉丽斯·史达琳 Clarice Starling
- 安东尼·霍普金斯 饰 汉尼拔·莱克特博士 Dr. Hannibal Lecter
- 斯科特·格伦 饰 杰克·克劳福德 Jack Crawford
- 安东尼·希尔德 饰 弗雷德里克·奇尔顿博士 Dr. Frederick Chilton
- 布鲁克·史密斯 饰 凯瑟琳·马丁 Catherine Martin

## 沉默的羔羊的视频和图片 · · · · · · ( 预告片2 | 视频评论2 · 添加 | 图片628 · 添加 )

## 沉默的羔羊的获奖情况 · · · · · · ( 全部 )

- 第64届奥斯卡金像奖
- 最佳影片
- 肯尼思·厄特 / 爱德华·萨克森 / 罗纳德·M·博兹曼

- 第41届柏林国际电影节
- 金熊奖 最佳影片(提名)
- 乔纳森·戴米

- 第15届日本电影学院奖
- 最佳外语片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  七宗罪

  致命ID

  恐怖游轮

  禁闭岛

  汉尼拔

  闪灵

  记忆碎片

  杀人回忆

  第六感

  电锯惊魂

我要写短评

## 沉默的羔羊的短评 · · · · · · ( 全部 133322 条 )

热门 / 最新 / 好友

### 11025 有用 亵渎电影 看过 2011-03-15 06:24:45

如果汉尼拜尔教授不整天嘴上念叨着吃人，和他共进晚餐一定是世界上最迷人的事情。★★★★★

### 8612 有用 阿让 看过 2012-09-08 12:05:09

正是因为米国没有卤煮火烧和烩羊杂，就连爆肚、溜肥肠，酱爆肝尖，火爆腰花什么的都没有，所以作为美食家的汉尼拔很尴尬，常常为了一份食材而绞尽脑汁，大费周章，其实。北京欢迎你，大可满足你顿顿吃卤煮的愿望。

### 2998 有用 UrthónaD'Mors 看过 2007-08-25 17:27:59

棒就一字，看完后记住那句话“勇敢的克拉丽斯，如果有一天你的羔羊停止了尖叫，你会来告诉我吗？”

### 2141 有用 芹菜 看过 2012-11-02 13:21:52

最后一个镜头与T-Bag神似!电影一般,不过汉尼拔越狱那段非常精彩!看评论有人自作聪明的评论这段屋子里怎么没有监视器?是电影一个致命BUG.明显故事背景时间没搞清楚,还不如说在汉尼拔身上植入一个GPS呢.

### 1867 有用 故城 看过 2020-03-18 10:46:45

二十年后再看，注意力已不在汉尼拔和福斯特身上。福斯特与她导师之间的关系倒吸引了我。沉默的羔羊，其实是女主本人，而导师恰好是压抑她的那个人（影片中男权笼罩的心理暗示当然还有好几处），他的伪善表现在三个地方，一是在葬礼时，他回避将案情告诉女主，后来又伪善地跟她解释给自己洗白；二是在女主寻找线索时把电话打给导师，听到他已经动用特种部队去抓人了，才知道导师根本没把他掌握的案情进展跟她提及，也根本不信任她的... 二十年后再看，注意力已不在汉尼拔和福斯特身上。福斯特与她导师之间的关系倒吸引了我。沉默的羔羊，其实是女主本人，而导师恰好是压抑她的那个人（影片中男权笼罩的心理暗示当然还有好几处），他的伪善表现在三个地方，一是在葬礼时，他回避将案情告诉女主，后来又伪善地跟她解释给自己洗白；二是在女主寻找线索时把电话打给导师，听到他已经动用特种部队去抓人了，才知道导师根本没把他掌握的案情进展跟她提及，也根本不信任她的意见；三是庆功会上，导师根本没有为她感到骄傲，反而意兴阑珊，提前离场了。这些细节，强化了女主沉默的羔羊的身份，如果没有汉尼拔的出现，谁会在乎这样“她”的感受，这也是整部影片成立的基础。第一次探监时，旁边“狱友”还用精液猥亵她，可是谁曾想，第二天汉尼拔便弄死了他，成全了两人的精神投靠。 (展开)

> 更多短评 133322条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 沉默的羔羊的影评 · · · · · · ( 全部 1149 条 )

热门 / 最新 / 好友
勤劳的小蜘蛛 2008-12-07 04:58:49

## 当无情的神爱上殉道的牧女

史黛琳并不是一个单纯的女人，只有无知的人才会真正的单纯。史黛琳的性格是复杂的，她理智聪明有野心，这是汉尼拔亲口说的，她也懂得颇为圆滑的处理人际关系。这些特质都是汉尼拔喜欢她的原因之一，汉尼拔说过他讨厌粗鲁无礼的人，而“礼节”“克制”这种东西恰恰是人类反动物... (展开)
15253 477 570回应 收起
hihiloving 2007-01-23 11:00:07

## 悬疑背后的悬疑

《沉默的羔羊》(The Silence of the Lambs)　剧情简介: 刚刚受训结束被分配到联邦调查局工作的见习特工克拉丽斯接受了一项艰巨的任务，寻找并缉捕一名外号叫“野牛比尔”的变态杀人犯。已经有不少年轻女子死在了他手上，并被剥去了部分皮肤。为了了解凶犯的特殊心理，寻找出隐... (展开)
2770 347 243回应 收起
品客 2009-07-19 17:31:53

## 《沉默的羔羊》镜头分析、运用及其它

这是一篇若干年前学生时代的作业，有部分删改。而且本人对于《沉默的羔羊》的摄影分析带有许多比较强烈的个人感觉和想法，也许有很多地方有错误或者是片面或幼稚，各位看官在阅读时请保留好自己的意见和想法。 接触沉默的羔羊还是在初中二年级的时候在校园的闭路电视台上，那... (展开)
1724 88 130回应 收起
静以待时 2012-06-30 08:47:09

## 对《沉默的羔羊》进行情节疑惑解答（部分）

这篇影评可能有剧透

第一部以惊悚片作为类型闯进1992年oscar殿堂，并一举拿下“最佳影片”“最佳导演”“最佳男主角”三满贯的经典之作————————————《The Silence of the Lambs》 至于影评，不多说，精彩的影评一刷一大版。刚看到有朋友发帖说对片中的故事情节不是很理解，我将这些... (展开)
895 261 224回应 收起
袁 2006-12-06 23:25:24

## “Quid pro quo”

因为专业英文课上有着好来坞二十多年资历的老师要讲这部片子，便买了碟重新看了一遍。以前一直是个电影欣赏者，现在念了电影研究生，得要求自己是个电影分析及实践者。所以之前看过一遍但没印象的片子等于没看过，还有人说看一百部片子不如看一部片一百遍。从此做为把看电影当... (展开)
463 111 67回应 收起
S 2010-09-30 12:42:48

## 存档：《沉默的羔羊》长镜头、人物出场、细节、悬念、结构分析

《沉默的羔羊》长镜头、人物出场、细节、悬念、结构分析 《沉默的羔羊》（The Silence of the Lambs, 1991） 基本信息 编剧：泰德•塔利（Ted Tally） 导演：乔纳森•戴米（Jonathan Demme） 摄影：塔克• 藤本（Tak Fujimoto） ¼br /> 类型：犯罪/惊悚 国家/地区... (展开)
393 17 20回应 收起
小龙女 2009-06-03 22:53:27

## 用精神分析法浅谈<沉默的羔羊>

这篇影评可能有剧透

史黛丽是联邦调查局的见习特工，她奉命去州立精神犯罪监狱拜访汉尼拔。汉尼拔是一位著名的精神分析专家，但是他有着吃人肉的嗜好，涉嫌杀害多名患者而被捕入狱。史黛丽拜访的意图是希望能让汉尼拔提供线索，缉捕一名外号为“野牛比尔”的变态杀人犯，他已经连续... (展开)
410 27 18回应 收起
普通人 2005-11-30 14:29:46

## 美女与野兽——《沉默的羔羊》

你最害怕的是什么？食人与剥人皮？绑架？身陷干涸的井底？解剖尸体？巨型昆虫？在黑暗中迷路？被看不到的人追赶？失去他人的信任？从阴影里跳出的生灵？知道你隐私的人？门在背后被关上？砍头？对性的曲解？还有矮小的女人和满满一电梯的高大男人站在一起？汤姆斯·哈利斯（原... (展开)
310 74 42回应 收起
Murderer 2006-05-12 13:36:05

## 你曾因此而沉默么？

近来闲来无事，又第n次重温了这部经典，真是好茶越品越浓，好片越看越触动，越看越深刻！经典是毋庸置疑的，经典是经的起时间的考验的，经典更不会被人们的口舌之争而磨灭，他会逐渐突破地域与人种的差异，以完成其不朽的价值。 汉尼拔那深邃的眼神，优雅的言谈举止，... (展开)
426 174 101回应 收起

> 更多影评 1149篇

添加新讨论

## 讨论区 · · · · · ·

汉尼拔画的克拉丽丝圣母像 | 来自清明雨 | 2 回应 | 2022-11-21 23:52:12
有几个细节不太明白 | 来自零井 | 21 回应 | 2022-11-21 22:14:15
女主是不是有夜盲症啊？ | 来自吃瓜群众代表 | 12 回应 | 2022-11-21 20:11:18
汉尼拔为什么喜欢吃人 | 来自一般般咯 | 3 回应 | 2022-11-20 22:12:24
优质的包包和廉价的鞋子？ | 来自苏格拉@底 | 24 回应 | 2022-11-20 19:24:34

> 去这部影片的讨论区（全部381条）

## 关于《沉默的羔羊》的问题 · · · · · · ( 全部56个 )

- 为什么女主的同事看她的眼神都怪怪的？ 5人回答
- 为什么汉尼拔博士要帮女主？他看上她了吗？ 22人回答

> 全部56个问题

## 在哪儿看这部电影 · · · · · ·

- 爱奇艺视频 VIP免费观看
- 哔哩哔哩 VIP免费观看
- 西瓜视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【真实犯罪】—— 真人真事改编案件（世界版1） (狷介有乌青)
- 心理学电影(一句话剧透,不喜勿入) (何学卿)
- 他们是高智商玩家 (中间元素)
- 7分以上的恐怖/惊悚电影 (冬至)

## 谁在看这部电影 · · · · · ·

- 有可乐也不给你
  2分钟前 看过
- 跳跃在心都草坪
  3分钟前 想看
- 没什么说说
  7分钟前 看过

1309617人看过 / 314614人想看

订阅沉默的羔羊的评论:
feed: rss 2.0